#include <windows.h>
#include <stdio.h>
#include "resource.h"
#include "LALANIO.h"

BOOL CALLBACK DlgProc(HWND, UINT, WPARAM, LPARAM);
BOOL connect(HWND hWnd, hLANIO *lanio);
void output(HWND hWnd, hLANIO lanio);
void input(HWND hWnd, hLANIO lanio);
BOOL connected = FALSE;
hLANIO lanio = 0;

int WINAPI WinMain(HINSTANCE hInstance, HINSTANCE hPrevInstance, LPSTR lpCmdLine, int nCmdShow)
{
	DialogBox(NULL, MAKEINTRESOURCE(IDD_LA2A3PSAMPLE), NULL, (DLGPROC)DlgProc);
	return 0;
}

BOOL CALLBACK DlgProc(HWND hWnd, UINT msg, WPARAM wParam, LPARAM lParam)
{
    switch( msg ){
	case WM_INITDIALOG:
		LALanioInit();
		return TRUE;
	case WM_CLOSE:
		LALanioEnd();
		EndDialog(hWnd, IDOK);
		return TRUE;
	case WM_COMMAND:
		switch( LOWORD(wParam) ){
		case IDCANCEL:
			LALanioEnd();
			EndDialog(hWnd, IDCANCEL);
			return TRUE;
		case IDC_CONNECT:
			if( IsDlgButtonChecked(hWnd, IDC_CONNECT) == BST_CHECKED ){
				// connecting
				if( connect(hWnd, &lanio) == TRUE ){
					connected = TRUE;
				} else {
					CheckDlgButton(hWnd, IDC_CONNECT, BST_UNCHECKED);
				}
				return TRUE;
			} else {
				// disconnecting
				LALanioClose(lanio);
				connected = FALSE;
			}
			return TRUE;
		case IDC_OUTPUT:
			if( connected != TRUE ){
				MessageBox(hWnd,"not connected",NULL,IDOK);
				return TRUE;
			}
			output(hWnd, lanio);
			return TRUE;
		case IDC_INPUT:
			if( connected != TRUE ){
				MessageBox(hWnd,"not connected",NULL,IDOK);
				return TRUE;
			}
			input(hWnd, lanio);
			return TRUE;
		}
	}
	return FALSE;
}

BOOL connect(HWND hWnd, hLANIO *lanio)
{
	char ipaddress[256];
	if( GetDlgItemText(hWnd, IDC_IPADDRESS, ipaddress, 256) == 0 ){
		return FALSE;
	}
	*lanio = LALanioConnectDirect(ipaddress, 2000);
	if( *lanio == -1 ){
		MessageBox(hWnd,"Connect error",NULL,IDOK);
		return FALSE;
	}
	return TRUE;
}

void output(HWND hWnd, hLANIO lanio)
{
	char valuestr[256];
	int value, err;

	if( GetDlgItemText(hWnd, IDC_AO1, valuestr, 256) != 0 ){
		value = atoi(valuestr);
		err = LALanioAOVoltage(lanio, 0, value);
		if( err == 0 ){
			MessageBox(hWnd,"Output error",NULL,IDOK);
			return;
		}
	}

	if( GetDlgItemText(hWnd, IDC_AO2, valuestr, 256) != 0 ){
		value = atoi(valuestr);
		err = LALanioAOVoltage(lanio, 1, value);
		if( err == 0 ){
			MessageBox(hWnd,"Output error",NULL,IDOK);
			return;
		}
	}
}

void input(HWND hWnd, hLANIO lanio)
{
	char resultstr[256];
	int input, err;
	err = LALanioDI(lanio, &input);
	if( err == 0 ){
		MessageBox(hWnd,"Input error",NULL,IDOK);
		return;
	}
	sprintf(resultstr, "DI1:%s DI2:%s DI3:%s",
		(input & 0x01) ? "ON" : "OFF",
		(input & 0x02) ? "ON" : "OFF",
		(input & 0x04) ? "ON" : "OFF" );
	SetDlgItemText(hWnd, IDC_DI, resultstr);
}
